[![Build Status](https://travis-ci.com/alesanfra/lora-gwmp.svg?branch=master)](https://travis-ci.com/alesanfra/lora-gwmp)
[![codecov](https://codecov.io/gh/alesanfra/lora-gwmp/branch/master/graph/badge.svg?token=GA5KCLADD6)](https://codecov.io/gh/alesanfra/lora-gwmp)

# Gateway Message Protocol (GWMP) parser


This is a simple utility for parsing GWMP messages used in LoRa and LoRaWAN networks.

## Installation

```bash
pip install gwmp
```

## Usage

```bash
gwmp parse my-file.txt --out parsed.csv --key hexadecimalkey
```
